@@ -20,8 +20,10 @@ I18n.reload!
 Responders::Routes = ActionDispatch::Routing::RouteSet.new
 Responders::Routes.draw do
   resources :news
-  get '/admin/:action', :controller => "admin/addresses"
-  get '/:controller(/:action(/:id))'
+  ActiveSupport::Deprecation.silence do
+    get '/admin/:action', controller: 'admin/addresses'
+    get '/:controller(/:action(/:id))'
+  end
 end
 
 class ApplicationController < ActionController::Base
@@ -41,6 +43,9 @@ end
 
 if ActionPack::VERSION::STRING >= '5.0.0'
   require 'rails-controller-testing'
+
+  ActionController::TestCase.include Rails::Controller::Testing::TestProcess
+  ActionController::TestCase.include Rails::Controller::Testing::TemplateAssertions
 else
   # TODO: Remove this compatibility monkeypatch when we drop support for Rails 4.2.
   class ActionController::TestCase
@@ -70,8 +75,7 @@ module ActionDispatch
   class Flash
     class FlashHash
       def used_keys
-        # Rails 3 || Rails 4
-        @used || @discard
+        @discard
       end
     end
   end
